%   The function Estim_SSRF_vn estimates the Spartan variogram of data. 
%   More precisely, it performs the following operations:
%   1. It loads a data set consisting of X, Y (location) and RF (data) values.
%   2. It estimates the empirical semivariogram
%   3. It performs a least-squares fit to find the optimal Spartan
%   variogram model
%
%   INPUT: 
%   data: [X Y RF] is an N x 3 matrix of data values
%   Nc: Number of Bins
%   Flag: Do we want the figure plotted? 1 is yes
%   MDIS Maximum Variogram cutoff distance COMPARED to maximum pair distance. 
%   I.e. MDIS=0.5 means the maximum distance is set as half the maximum
%   distance of the pairs. (Default = 0.425)
%   Weighting: 1 Number of pairs. 2 inverse of square empirical variogram.
%           If no weighting option is used, simple least squares is used.
%
%   OUTPUT:
%   Param=[h0, h1, xi, C0]
%   lags, variogram values (empirical)
%   lags, variogram values (SSRF model)
%
%   Example:
% 
%   [Param, lags, varioz, lagsn,variom]=Estim_SSRF_vn(data, Nc, Flag, MDIS, Weighting);
%
%   This script requires the following functions:
%   WLS_SSRF, EMPIRVAR, COV_SSRF_EXP
%
%==========================================================================
%
%  Copyright (C) 2014  Dionisis Hristopulos and Andreas Pavlidis
%   email: dionisi@mred.tuc.gr
%
%  This program is free software; you can redistribute it and/or modify it
%  under the terms of the GNU General Public License as published by the
%  Free Software Foundation (version 2 of the License or  later version).
%
%  This program is distributed WITHOUT ANY WARRANTY.
%  See the GNU General Public License for more details.
%==========================================================================

function [Param, lags, varioz, lagsn,variom]=Estim_SSRF_vn(data, Nc, Flag, MDIS, Weighting)

options = optimset('display','final','TolX',1e-7,'TolFun',1e-6,...
   'MaxFunEvals',10^5,'MaxIter',10^5); 

if nargin>2 & Flag==1
    Flag=1; % Flag = Yes, plot figure
else
    Flag=0;
end

if nargin<4
    MDIS=0.425;
end
if MDIS>1
    MDIS=1;
end

if nargin<5
    Weighting=0;
end

Nugesti=1; % We want nugget estimate
%==========================================================================
%   LOAD DATA
%==========================================================================

x = data(:,1); 
y = data(:,2); 
rf = data(:,3); 

%==========================================================================
%   INITIALIZE SSRF PARAMETERS   
%==========================================================================

eta1_0 = 2; 
xi_0 = mean(max(pdist2(data(:,1:2),data(1:2))))/10;

if Nugesti==1
    [~,varsrf0]= cov_ssrf_exp(3,eps,[1 eta1_0 xi_0 eps],0);
    eta0_0 = var(rf)/varsrf0;
    C0_0=var(rf)/25;
    Param0 = [eta0_0 eta1_0 xi_0 C0_0];
    LB=[eps -2+eps eps eps];
    UB=[inf inf inf inf];

else
    [~,varsrf0]= cov_ssrf_exp(3,eps,[1 eta1_0 xi_0],0);
    eta0_0 = var(rf)/varsrf0;
    Param0 = [eta0_0 eta1_0 xi_0];
end



%==========================================================================
%   ESTIMATE EMPIRICAL VARIOGRAM   
%==========================================================================

[varioz, lags, npairs]= empirvar(Nc,pi/2,pi/2, x, y, rf, 0, MDIS);

%==========================================================================
%   DETERMINE THE OPTIMAL SSRF VARIOGRAM MODEL USING LEAST SQUARES FIT 
%==========================================================================

 % Optimization
[Param,fval,flagg,output] = fminsearch('wls_ssrf',Param0,options,lags,...
   varioz,npairs,Weighting);

if Nugesti==1
    C0=max(Param(4),0);
end

%==========================================================================
%   PLOT RESULTS   
%==========================================================================
% 

 lagsn = linspace(0,max(lags),200); 
 [~,varsrf] = cov_ssrf_exp(3,eps,Param,0);
 [~,variosrf] = cov_ssrf_exp(3,lagsn,Param,0);
 
 variom = varsrf - variosrf;
 if Nugesti==1
     variom=variom+C0;
 end
 
 if Flag==1
     figure
hold on; 
plot(lags, varioz, 'o','MarkerSize',9)
plot(lagsn,variom,'k','LineWidth',2); 
legend('Exper','SSRF','Location','Best');
 end

end

