%   The function Estim_SSRF_vn estimates the Spartan variogram of spatial data. 
%   More precisely, it performs the following operations:
%   1. It loads a data set consisting of X, Y (location) and RF (data) values.
%   2. It estimates the empirical semivariogram
%   3. It performs a least-squares fit to find the optimal Spartan
%   variogram model
%
%   INPUT: 
%   data: [X Y RF] is an N x 3 matrix of data values
%   Nc: Number of Bins
%   Flag: Do we want the figure plotted? 1 is yes
%   MDIS Maximum Variogram cutoff distance COMPARED to maximum pair distance. 
%   I.e. MDIS=0.5 means the maximum distance is set as half the maximum
%   distance of the pairs. (Default = 0.425)
%   Weighting: 1 Number of pairs. 2 inverse of square empirical variogram.
%           If no weighting option is used, simple least squares is used.
%
%   OUTPUT:
%   Param=[h0, h1, xi, C0]
%   lags, variogram values (empirical)
%   lags, variogram values (SSRF model)
%
%   Example:
% 
%   [Param, lags, varioz, lagsn,variom]=Estim_SSRF_vn(data, Nc, Flag, MDIS, Weighting);
%
%   This script requires the following functions:
%   WLS_SSRF, EMPIRVAR, COV_SSRF_EXP
%
%==========================================================================
%
%  Copyright (C) 2014  Dionisis Hristopulos and Andreas Pavlidis
%   email: dionisi@mred.tuc.gr
%
%  This program is free software; you can redistribute it and/or modify it
%  under the terms of the GNU General Public License as published by the
%  Free Software Foundation (version 2 of the License or  later version).
%
%  This program is distributed WITHOUT ANY WARRANTY.
%  See the GNU General Public License for more details.
%========================================================================== 
%   EXAMPLES OF USE
%==========================================================================
% Generate data with exponential covariance function with sill = 2 and 
% range = 3 
%==========================================================================
% COV= @(x) 2*exp(-x);
% Loc=rand(150,2)*10; 
% DMAT=pdist2(Loc,Loc);
% COVMAT=COV(DMAT)+eye(150)*0.3; 
% Covariance matrix, including nugget effect with C0=0.3
% VALUE=sqrtm(COVMAT)*randn(150,1);
%==========================================================================
% Estimating the SSRF parameters at 15 different lag distances
%==========================================================================
% [Param]=Estim_SSRF_vn([Loc VALUE], 15); 
%==========================================================================
% Since MDIS is not defined, the variogram lags go up to 42.5% of the
% maximum pair distance. 
% Since Weighting is not defined, the SSRF variogram model is fitted using 
% least squares.
% 
%==========================================================================
% Estimating the parameters of the SSRF at 15 different lag distances with 
% figure
%==========================================================================
% [Param]=Estim_SSRF_vn([Loc VALUE], 15, 1, 0.5, 1); 
%==========================================================================
% Since MDIS=0.5, the variogram lags go up to half of the maximum distance. 
% Since Weighting is 1, the SSRF variogram model is fit using weighted least
% squares, weighted by the number of pairs in the empirical variogram.








